@@ -104,6 +104,8 @@ SSLConfigParams::reset()
       nullptr;
   server_tls13_cipher_suites = nullptr;
   client_tls13_cipher_suites = nullptr;
+  server_groups_list         = nullptr;
+  client_groups_list         = nullptr;
   client_ctx                 = nullptr;
   clientCertLevel = client_verify_depth = verify_depth = clientVerify = 0;
   ssl_ctx_options                                                     = SSL_OP_NO_SSLv2 | SSL_OP_NO_SSLv3;
@@ -137,6 +139,8 @@ SSLConfigParams::cleanup()
 
   server_tls13_cipher_suites = (char *)ats_free_null(server_tls13_cipher_suites);
   client_tls13_cipher_suites = (char *)ats_free_null(client_tls13_cipher_suites);
+  server_groups_list         = (char *)ats_free_null(server_groups_list);
+  client_groups_list         = (char *)ats_free_null(client_groups_list);
 
   freeCTXmap();
   SSLReleaseContext(client_ctx);
@@ -320,6 +324,8 @@ SSLConfigParams::initialize()
   REC_ReadConfigInt32(async_handshake_enabled, "proxy.config.ssl.async.handshake.enabled");
   REC_ReadConfigStringAlloc(engine_conf_file, "proxy.config.ssl.engine.conf_file");
 
+  REC_ReadConfigStringAlloc(server_groups_list, "proxy.config.ssl.server.groups_list");
+
   // ++++++++++++++++++++++++ Client part ++++++++++++++++++++
   client_verify_depth = 7;
   REC_EstablishStaticConfigByte(clientVerify, "proxy.config.ssl.client.verify.server");
@@ -346,6 +352,8 @@ SSLConfigParams::initialize()
   ats_free(clientCACertRelativePath);
   ats_free(ssl_client_ca_cert_filename);
 
+  REC_ReadConfigStringAlloc(client_groups_list, "proxy.config.ssl.client.groups_list");
+
   // Enable/disable sni mapping
   REC_ReadConfigInteger(sni_map_enable, "proxy.config.ssl.sni.map.enable");
 
